@@ -3,7 +3,7 @@ use kadmin::KAdmin;
 #[cfg(feature = "client")]
 use kadmin::KAdminImpl;
 #[cfg(feature = "local")]
-use kadmin::{KAdminDbArgs, KAdminParams};
+use kadmin::{DbArgs, Params};
 use serial_test::serial;
 mod k5test;
 use k5test::K5Test;
@@ -13,8 +13,9 @@ use k5test::K5Test;
 #[serial]
 fn with_password() -> Result<()> {
     let realm = K5Test::new()?;
-    let kadmin = KAdmin::builder().with_password(&realm.admin_princ()?, &realm.password("admin")?)?;
-    kadmin.list_principals("*")?;
+    let kadmin =
+        KAdmin::builder().with_password(&realm.admin_princ()?, &realm.password("admin")?)?;
+    kadmin.list_principals(None)?;
     Ok(())
 }
 
@@ -23,8 +24,9 @@ fn with_password() -> Result<()> {
 #[serial]
 fn with_keytab() -> Result<()> {
     let realm = K5Test::new()?;
-    let kadmin = KAdmin::builder().with_password(&realm.admin_princ()?, &realm.password("admin")?)?;
-    kadmin.list_principals("*")?;
+    let kadmin =
+        KAdmin::builder().with_password(&realm.admin_princ()?, &realm.password("admin")?)?;
+    kadmin.list_principals(None)?;
     Ok(())
 }
 
@@ -35,8 +37,9 @@ fn with_ccache() -> Result<()> {
     let realm = K5Test::new()?;
     realm.prep_kadmin()?;
     let kadmin_ccache = realm.kadmin_ccache()?;
-    let kadmin = KAdmin::builder().with_ccache(Some(&realm.admin_princ()?), Some(&kadmin_ccache))?;
-    kadmin.list_principals("*")?;
+    let kadmin =
+        KAdmin::builder().with_ccache(Some(&realm.admin_princ()?), Some(&kadmin_ccache))?;
+    kadmin.list_principals(None)?;
     Ok(())
 }
 
@@ -45,16 +48,19 @@ fn with_ccache() -> Result<()> {
 #[serial]
 fn with_local() -> Result<()> {
     let realm = K5Test::new()?;
-    let db_args = KAdminDbArgs::builder()
+    let db_args = DbArgs::builder()
         .arg("dbname", Some(&format!("{}/db", realm.tmpdir()?)))
         .build()?;
-    let params = KAdminParams::builder()
+    let params = Params::builder()
         .dbname(&format!("{}/db", realm.tmpdir()?))
         .acl_file(&format!("{}/acl", realm.tmpdir()?))
         .dict_file(&format!("{}/dict", realm.tmpdir()?))
         .stash_file(&format!("{}/stash", realm.tmpdir()?))
         .build()?;
-    let _kadmin = KAdmin::builder().db_args(db_args).params(params).with_local()?;
+    let _kadmin = KAdmin::builder()
+        .db_args(db_args)
+        .params(params)
+        .with_local()?;
     Ok(())
 }
 
@@ -64,7 +70,7 @@ mod sync {
     use kadmin::KAdminImpl;
     use kadmin::sync::KAdmin;
     #[cfg(feature = "local")]
-    use kadmin::{KAdminDbArgs, KAdminParams};
+    use kadmin::{DbArgs, Params};
     use serial_test::serial;
 
     use crate::K5Test;
@@ -74,8 +80,9 @@ mod sync {
     #[serial]
     fn with_password() -> Result<()> {
         let realm = K5Test::new()?;
-        let kadmin = KAdmin::builder().with_password(&realm.admin_princ()?, &realm.password("admin")?)?;
-        kadmin.list_principals("*")?;
+        let kadmin =
+            KAdmin::builder().with_password(&realm.admin_princ()?, &realm.password("admin")?)?;
+        kadmin.list_principals(None)?;
         Ok(())
     }
 
@@ -84,8 +91,9 @@ mod sync {
     #[serial]
     fn with_keytab() -> Result<()> {
         let realm = K5Test::new()?;
-        let kadmin = KAdmin::builder().with_password(&realm.admin_princ()?, &realm.password("admin")?)?;
-        kadmin.list_principals("*")?;
+        let kadmin =
+            KAdmin::builder().with_password(&realm.admin_princ()?, &realm.password("admin")?)?;
+        kadmin.list_principals(None)?;
         Ok(())
     }
 
@@ -96,8 +104,9 @@ mod sync {
         let realm = K5Test::new()?;
         realm.prep_kadmin()?;
         let kadmin_ccache = realm.kadmin_ccache()?;
-        let kadmin = KAdmin::builder().with_ccache(Some(&realm.admin_princ()?), Some(&kadmin_ccache))?;
-        kadmin.list_principals("*")?;
+        let kadmin =
+            KAdmin::builder().with_ccache(Some(&realm.admin_princ()?), Some(&kadmin_ccache))?;
+        kadmin.list_principals(None)?;
         Ok(())
     }
 
@@ -106,8 +115,9 @@ mod sync {
     #[serial]
     fn with_local() -> Result<()> {
         let realm = K5Test::new()?;
-        let db_args_builder = KAdminDbArgs::builder().arg("dbname", Some(&format!("{}/db", realm.tmpdir()?)));
-        let params_builder = KAdminParams::builder()
+        let db_args_builder =
+            DbArgs::builder().arg("dbname", Some(&format!("{}/db", realm.tmpdir()?)));
+        let params_builder = Params::builder()
             .dbname(&format!("{}/db", realm.tmpdir()?))
             .acl_file(&format!("{}/acl", realm.tmpdir()?))
             .dict_file(&format!("{}/dict", realm.tmpdir()?))
