@@ -1,8 +1,9 @@
-from kadmin._lib import KAdmin, Principal, Params, DbArgs, __version__
+from kadmin._lib import KAdmin, Policy, Principal, Params, DbArgs, __version__
 
 __all__ = (
     "__version__",
     "KAdmin",
+    "Policy",
     "Principal",
     "Params",
     "DbArgs",
