@@ -7,6 +7,11 @@ NullPointerDereference = exceptions.NullPointerDereference
 CStringConversion = exceptions.CStringConversion
 CStringImportFromVec = exceptions.CStringImportFromVec
 StringConversion = exceptions.StringConversion
+ThreadSendError = exceptions.ThreadSendError
+ThreadRecvError = exceptions.ThreadRecvError
+TimestampConversion = exceptions.TimestampConversion
+DateTimeConversion = exceptions.DateTimeConversion
+DurationConversion = exceptions.DurationConversion
 
 __all__ = (
     "PyKAdminException",
@@ -16,4 +21,9 @@ __all__ = (
     "CStringConversion",
     "CStringImportFromVec",
     "StringConversion",
+    "ThreadSendError",
+    "ThreadRecvError",
+    "TimestampConversion",
+    "DateTimeConversion",
+    "DurationConversion",
 )
